@@ -4,7 +4,7 @@
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
-#define g_marshal_value_peek_char(v)     g_value_get_char (v)
+#define g_marshal_value_peek_char(v)     g_value_get_schar (v)
 #define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
 #define g_marshal_value_peek_int(v)      g_value_get_int (v)
 #define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
@@ -49,7 +49,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* INT:STRING,STRING (/home/wk/w/gpa/src/gpa-marshal.list:1) */
+/* INT:STRING,STRING (/home/wk/s/gpa/src/gpa-marshal.list:1) */
 void
 gpa_marshal_INT__STRING_STRING (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
