@@ -1,6 +1,6 @@
 /* gpa.c - The GNU Privacy Assistant main file.
    Copyright (C) 2000-2002 G-N-U GmbH.
-   Copyright (C) 2005, 2008, 2012, 2014 g10 Code GmbH.
+   Copyright (C) 2005, 2008, 2012, 2014, 2015 g10 Code GmbH.
 
    This file is part of GPA
 
@@ -87,7 +87,7 @@ static gpa_args_t args;
 /* The copyright notice.  */
 static const char *copyright =
 "Copyright (C) 2000-2002 Miguel Coca, G-N-U GmbH, Intevation GmbH.\n"
-"Copyright (C) 2005-2014 g10 Code GmbH.\n"
+"Copyright (C) 2005-2015 g10 Code GmbH.\n"
 "This program comes with ABSOLUTELY NO WARRANTY.\n"
 "This is free software, and you are welcome to redistribute it\n"
 "under certain conditions.  See the file COPYING for details.\n";
@@ -524,24 +524,10 @@ main (int argc, char *argv[])
      that the agent has been startet. */
   gpa_start_agent ();
 
-  /* Handle command line options.  */
-  cms_hack = !args.disable_x509;
-
-  /* Start the key manger by default.  */
-  if (!args.start_key_manager
-      && !args.start_file_manager
-      && !args.start_clipboard
-      && !args.start_settings
-      && !args.start_card_manager
-      )
-    args.start_key_manager = TRUE;
-
-  /* Note: We can not use GPGME's engine info, as that returns NULL
-     (default) for home_dir.  Consider improving GPGME to get it from
-     there, or using gpgconf (via GPGME).  */
   gnupg_homedir = default_homedir ();
-  /* FIXME: GnuPG can not create a key if its home directory is
-     missing.  We help it out here.  Should be fixed in GnuPG.  */
+
+  /* GnuPG can not create a key if its home directory is missing.  We
+     help it out here.  Should be fixed in GnuPG.  */
   if (! g_file_test (gnupg_homedir, G_FILE_TEST_IS_DIR))
     g_mkdir (gnupg_homedir, 0700);
 
@@ -562,6 +548,26 @@ main (int argc, char *argv[])
       return 0;
     }
 
+  /* Handle command line options.  */
+  cms_hack = !args.disable_x509;
+
+  /* Start the default component.  */
+  if (!args.start_key_manager
+      && !args.start_file_manager
+      && !args.start_clipboard
+      && !args.start_settings
+      && !args.start_card_manager
+      )
+    {
+      /* The default action is to start the clipboard.  However, if we
+         have not yet created a key we remind the user by starting
+         with the key manager dialog.  */
+      if (key_manager_maybe_firsttime ())
+        args.start_key_manager = TRUE;
+      else
+        args.start_clipboard = TRUE;
+    }
+
 
   /* Check whether we need to start a server or to simply open a
      window in an already running server.  */
